@@ -82,8 +82,6 @@ void dmResetSub() {
         
         delete dmInt::pProgress;
         dmInt::pProgress = 0;
-    } catch (const string& e) {
-        ::Rf_error(e.c_str());
     } catch(...) {
         ::Rf_error("C++ exception (unknown reason)");
     }
@@ -93,8 +91,6 @@ void dmResetSub() {
 int dmGetBatchSize() {
     try {
         return dmInt::batchSize;
-    } catch (const string& e) {
-        ::Rf_error(e.c_str());
     } catch(...) {
         ::Rf_error("C++ exception (unknown reason)");
     }
@@ -104,8 +100,6 @@ int dmGetBatchSize() {
 int dmGetMaxSize() {
     try {
         return dmInt::maxSize;
-    } catch (const string& e) {
-        ::Rf_error(e.c_str());
     } catch(...) {
         ::Rf_error("C++ exception (unknown reason)");
     }
@@ -124,9 +118,6 @@ void dmDataSourceRead(const std::string& inFileName) {
         dmInt::pDataSource = new DataSource();
         dmInt::pDataSource->read(is);
         is.close();
-    
-    } catch (const string& e) {
-        ::Rf_error(e.c_str());
     } catch(...) {
         ::Rf_error("C++ exception (unknown reason)");
     }
@@ -149,9 +140,6 @@ void dmGenerativeDataRead(const std::string& inFileName) {
         if(dmInt::pGenerativeData->getNormalizedSize() > dmInt::maxSize) {
             throw string(dmInt::cMaxSizeExceeded);
         }
-    
-    } catch (const string& e) {
-        ::Rf_error(e.c_str());
     } catch(...) {
         ::Rf_error("C++ exception (unknown reason)");
     }
@@ -166,8 +154,6 @@ std::vector<float> dmDataSourceGetNormalizedDataRandom(int rowCount) {
     
         std::vector<float> v = dmInt::pDataSource->getNormalizedDataRandom(rowCount);
         return v;
-    } catch (const string& e) {
-        ::Rf_error(e.c_str());
     } catch(...) {
         ::Rf_error("C++ exception (unknown reason)");
     }
@@ -194,8 +180,6 @@ std::vector<std::vector<float>> dmDataSourceGetDataRandom(float percent) {
         }
     
         return v;
-    } catch (const string& e) {
-        ::Rf_error(e.c_str());
     } catch(...) {
         ::Rf_error("C++ exception (unknown reason)");
     }
@@ -210,8 +194,6 @@ std::vector<float> dmGenerativeDataGetNormalizedDataRandom(int rowCount) {
     
         std::vector<float> v = ((DataSource*)dmInt::pGenerativeData)->getNormalizedDataRandom(rowCount);
         return v;
-    } catch (const string& e) {
-        ::Rf_error(e.c_str());
     } catch(...) {
         ::Rf_error("C++ exception (unknown reason)");
     }
@@ -226,8 +208,6 @@ std::vector<std::vector<float>> dmGenerativeDataGetNormalizedDataRandomWithDensi
     
         vector<vector<float>> v = dmInt::pGenerativeData->getNormalizedDataRandomWithDensities(rowCount);
         return v;
-    } catch (const string& e) {
-        ::Rf_error(e.c_str());
     } catch(...) {
         ::Rf_error("C++ exception (unknown reason)");
     }
@@ -242,8 +222,6 @@ std::vector<float> dmEvaluateCopyDataSourceGetNormalizedData(int row, int rowCou
     
         std::vector<float> v = dmInt::pEvaluateCopyDataSource->getNormalizedData(row - 1, rowCount);
         return v;
-    } catch (const string& e) {
-        ::Rf_error(e.c_str());
     } catch(...) {
         ::Rf_error("C++ exception (unknown reason)");
     }
@@ -257,8 +235,6 @@ int dmGetDataSourceDimension() {
         }
     
         return dmInt::pDataModel->getDataSource().getDimension();
-    } catch (const string& e) {
-        ::Rf_error(e.c_str());
     } catch(...) {
         ::Rf_error("C++ exception (unknown reason)");
     }
@@ -272,8 +248,6 @@ int dmGetGenerativeDataDimension() {
         }
     
         return dmInt::pGenerativeData->getDimension();
-    } catch (const string& e) {
-        ::Rf_error(e.c_str());
     } catch(...) {
         ::Rf_error("C++ exception (unknown reason)");
     }
@@ -287,8 +261,6 @@ int dmGetNormalizedSize() {
         }
     
         return dmInt::pGenerativeData->getNormalizedSize();
-    } catch (const string& e) {
-        ::Rf_error(e.c_str());
     } catch(...) {
         ::Rf_error("C++ exception (unknown reason)");
     }
@@ -302,8 +274,6 @@ int dmGetEvaluateCopyDataSourceNormalizedSize() {
         }
     
         return dmInt::pEvaluateCopyDataSource->getNormalizedSize();
-    } catch (const string& e) {
-        ::Rf_error(e.c_str());
     } catch(...) {
         ::Rf_error("C++ exception (unknown reason)");
     }
@@ -313,8 +283,6 @@ int dmGetEvaluateCopyDataSourceNormalizedSize() {
 std::string dmBuildFileName(const std::string& fileName, const std::string& extension) {
     try {
         return BuildFileName()(GetFileName()(fileName), extension);
-    } catch (const string& e) {
-        ::Rf_error(e.c_str());
     } catch(...) {
         ::Rf_error("C++ exception (unknown reason)");
     }
@@ -334,8 +302,6 @@ void dmWriteWithReadingTrainedModel(const std::string& outFileName) {
     
         dmInt::pDataModel->writeWithReadingTrainedModel(os, GetFileName()(outFileName));
         os.close();
-    } catch (const string& e) {
-        ::Rf_error(e.c_str());
     } catch(...) {
         ::Rf_error("C++ exception (unknown reason)");
     }
@@ -356,8 +322,6 @@ void dmWrite(const std::string& outFileName) {
     
         dmInt::pDataModel->write(os, GetFileName()(outFileName));
         os.close();
-    } catch (const string& e) {
-        ::Rf_error(e.c_str());
     } catch(...) {
         ::Rf_error("C++ exception (unknown reason)");
     }
@@ -377,8 +341,6 @@ void dmReadDataModel(const std::string& inFileName) {
     
         dmInt::pDataModel->read(is, GetFileName()(inFileName));
         is.close();
-    } catch (const string& e) {
-        ::Rf_error(e.c_str());
     } catch(...) {
         ::Rf_error("C++ exception (unknown reason)");
     }
@@ -404,9 +366,6 @@ void dmEvaluateDataSourceRead(const std::string& inFileName) {
     
         NormalizeData normalizeData;
         normalizeData.normalize(*dmInt::pEvaluateCopyDataSource, false);
-    
-    } catch (const string& e) {
-        ::Rf_error(e.c_str());
     } catch(...) {
         ::Rf_error("C++ exception (unknown reason)");
     }
@@ -424,8 +383,6 @@ std::vector<std::vector<float>> dmGetEvaluateCopyDataSourceNormalizedData(int ro
         v[1] = dmInt::pEvaluateCopyDataSource->getDenormalizedData(row - 1, rowCount);
         
         return v;
-    } catch (const string& e) {
-        ::Rf_error(e.c_str());
     } catch(...) {
         ::Rf_error("C++ exception (unknown reason)");
     }
@@ -439,8 +396,6 @@ std::vector<float> dmGetEvaluateCopyDataSourceDenormalizedData(int row, int rowC
         }
     
         return dmInt::pEvaluateCopyDataSource->getDenormalizedData(row - 1, rowCount);
-    } catch (const string& e) {
-        ::Rf_error(e.c_str());
     } catch(...) {
         ::Rf_error("C++ exception (unknown reason)");
     }
@@ -459,8 +414,6 @@ std::vector<std::wstring> dmGetNumberVectorIndexNames(std::vector<int>& numberVe
         }
         vector<wstring> numberVectorIndexNames = dmInt::pGenerativeData->getNumbeVectorIndexNames(indexVector);
         return numberVectorIndexNames;
-    } catch (const string& e) {
-        ::Rf_error(e.c_str());
     } catch(...) {
         ::Rf_error("C++ exception (unknown reason)");
     }
@@ -470,8 +423,6 @@ std::vector<std::wstring> dmGetNumberVectorIndexNames(std::vector<int>& numberVe
 std::string dmGetValue(float level) {
     try {
         return GetValue()(level);
-    } catch (const string& e) {
-        ::Rf_error(e.c_str());
     } catch(...) {
         ::Rf_error("C++ exception (unknown reason)");
     }
@@ -485,8 +436,6 @@ std::vector<float> dmGenerativeDataGetNormalizedData(int row, int rowCount) {
         }
         std::vector<float> v = ((DataSource*)dmInt::pGenerativeData)->getNormalizedData(row - 1, rowCount);
         return v;
-    } catch (const string& e) {
-        ::Rf_error(e.c_str());
     } catch(...) {
         ::Rf_error("C++ exception (unknown reason)");
     }
@@ -512,8 +461,6 @@ List dmGetRow(int index) {
             }
         }
         return list;
-    } catch (const string& e) {
-        ::Rf_error(e.c_str());
     } catch(...) {
         ::Rf_error("C++ exception (unknown reason)");
     }
@@ -532,8 +479,6 @@ void dmReadVolumeElementGraph(const std::string& inFileName) {
         dmInt::pVolumeElementGraph = new VolumeElementGraph();
         dmInt::pVolumeElementGraph->read(is);
         is.close();
-    } catch (const string& e) {
-        ::Rf_error(e.c_str());
     } catch(...) {
         ::Rf_error("C++ exception (unknown reason)");
     }
@@ -554,9 +499,6 @@ void dmWriteVolumeElementGraph(const std::string& outFileName) {
   
         dmInt::pVolumeElementGraph->write(os);
         os.close();
-    
-    } catch (const string& e) {
-        ::Rf_error(e.c_str());
     } catch(...) {
         ::Rf_error("C++ exception (unknown reason)");
     }
@@ -570,8 +512,6 @@ void dmAddVolumeElementsSub(std::vector<float>& volumeElementValues, std::vector
         }
     
         dmInt::pVolumeElementGraph->addVolumeElements(volumeElementValues, dimensions, indexBegin - 1, level, dmInt::pProgress);
-    } catch (const string& e) {
-        ::Rf_error(e.c_str());
     } catch(...) {
         ::Rf_error("C++ exception (unknown reason)");
     }
@@ -588,8 +528,6 @@ void dmBuildVolumeElements() {
         }
     
         dmInt::pVolumeElementGraph->buildVolumeElements();
-    } catch (const string& e) {
-        ::Rf_error(e.c_str());
     } catch(...) {
         ::Rf_error("C++ exception (unknown reason)");
     }
@@ -606,8 +544,6 @@ void dmBuildVolumeElementTree() {
         }
     
         dmInt::pVolumeElementGraph->buildVolumeElementTree(dmInt::pProgress);
-    } catch (const string& e) {
-        ::Rf_error(e.c_str());
     } catch(...) {
         ::Rf_error("C++ exception (unknown reason)");
     }
@@ -627,8 +563,6 @@ void dmBuildVolumeElementGraph() {
         }
     
         dmInt::pVolumeElementGraph->buildVolumeElementGraphIterative(dmInt::nNearestNeighborDistances, dmInt::nNearestNeighbors, dmInt::buildGraphIterations, true, dmInt::pProgress);
-    } catch (const string& e) {
-        ::Rf_error(e.c_str());
     } catch(...) {
         ::Rf_error("C++ exception (unknown reason)");
     }
@@ -664,8 +598,6 @@ void dmAddVolumeElementGraph() {
         
         delete dmInt::pVolumeElementGraph;
         dmInt::pVolumeElementGraph = 0;
-    } catch (const string& e) {
-        ::Rf_error(e.c_str());
     } catch(...) {
         ::Rf_error("C++ exception (unknown reason)");
     }
@@ -684,8 +616,6 @@ int dmBuildMetricSubspacesSub() {
     
         int c = dmInt::pVolumeElementGraph->buildMetricSubspaces(dmInt::minMetricSubspaceSize);
         return c;
-    } catch (const string& e) {
-        ::Rf_error(e.c_str());
     } catch(...) {
         ::Rf_error("C++ exception (unknown reason)");
     }
@@ -710,8 +640,6 @@ std::vector<std::vector<float>> dmGetGenerativeDataRandom(float percent) {
             v[1].insert(v[1].end(), numberVector.begin(), numberVector.end());
         }
         return v;
-    } catch (const string& e) {
-        ::Rf_error(e.c_str());
     } catch(...) {
         ::Rf_error("C++ exception (unknown reason)");
     }
@@ -742,8 +670,6 @@ std::vector<float> dmGetMetricSubspaceDenormalizedGenerativeData(float level, in
         }
         
         return metricSubspaceData;
-    } catch (const string& e) {
-        ::Rf_error(e.c_str());
     } catch(...) {
         ::Rf_error("C++ exception (unknown reason)");
     }
@@ -766,8 +692,6 @@ std::vector<int> dmGetMetricSubspaceIndices(float level, std::vector<std::string
         }
     
         return metricSubspacesIndices;
-    } catch (const string& e) {
-        ::Rf_error(e.c_str());
     } catch(...) {
         ::Rf_error("C++ exception (unknown reason)");
     }
@@ -797,8 +721,6 @@ List dmGetAdjacentVolumeElementIndices(int index) {
         }
     
         return list;
-    } catch (const string& e) {
-        ::Rf_error(e.c_str());
     } catch(...) {
         ::Rf_error("C++ exception (unknown reason)");
     }
@@ -826,8 +748,6 @@ float dmGetMax(int i) {
             throw string(cInvalidColumnType);
         }
         return max;
-    } catch (const string& e) {
-        ::Rf_error(e.c_str());
     } catch(...) {
         ::Rf_error("C++ exception (unknown reason)");
     }
@@ -855,8 +775,6 @@ float dmGetMin(int i) {
             throw string(cInvalidColumnType);
         }
         return min;
-    } catch (const string& e) {
-        ::Rf_error(e.c_str());
     } catch(...) {
         ::Rf_error("C++ exception (unknown reason)");
     }
@@ -881,8 +799,6 @@ std::vector<float> dmGetLevels() {
         }
 
         return dmInt::pDataModel->getLevels();
-    } catch (const string& e) {
-        ::Rf_error(e.c_str());
     } catch(...) {
         ::Rf_error("C++ exception (unknown reason)");
     }
@@ -920,8 +836,6 @@ List dmGetMetricSubspaceProperties(float level) {
             }
         }
         return levelMetricSubspaceList;    
-    } catch (const string& e) {
-        ::Rf_error(e.c_str());
     } catch(...) {
         ::Rf_error("C++ exception (unknown reason)");
     }
@@ -935,8 +849,6 @@ void dmRemoveMetricSubspacesSub(float level) {
         }
 
         dmInt::pDataModel->removeMetricSubspaces(level);
-    } catch (const string& e) {
-        ::Rf_error(e.c_str());
     } catch(...) {
         ::Rf_error("C++ exception (unknown reason)");
     }
@@ -960,8 +872,6 @@ std::vector<float> dmNormalizedDataRecord(List dataRecord) {
         vector<float> normalizedNumberVector = normalizeData.getNormalizedNumberVector(dmInt::pDataModel->getDataSource() , numberVector);
         
         return normalizedNumberVector;
-    } catch (const string& e) {
-        ::Rf_error(e.c_str());
     } catch(...) {
         ::Rf_error("C++ exception (unknown reason)");
     }
@@ -1027,8 +937,6 @@ List dmGetMetricSubspacesSub(List dataRecord, float level) {
         }
         
         return levelMetricSubspaceList;
-    } catch (const string& e) {
-        ::Rf_error(e.c_str());
     } catch(...) {
         ::Rf_error("C++ exception (unknown reason)");
     }
@@ -1117,8 +1025,6 @@ List dmMetricSubspaceLabelPointsSub(float lLevel, float rLevel, float percent, s
         metricSubspaceKeyPoints.insert(metricSubspaceKeyPoints.end(), metricSubspaceLabels);
         
         return metricSubspaceKeyPoints;
-    } catch (const string& e) {
-        ::Rf_error(e.c_str());
     } catch(...) {
         ::Rf_error("C++ exception (unknown reason)");
     }
@@ -1138,8 +1044,6 @@ std::vector<int> dmSortLevelIndices(std::vector<float>& levels) {
             sortedLevelIndices.push_back(levelIndexPairs[i].second);
         }
         return sortedLevelIndices;
-    } catch (const string& e) {
-        ::Rf_error(e.c_str());
     } catch(...) {
         ::Rf_error("C++ exception (unknown reason)");
     }
